function [tn,un,vn]=euler2(f1,f2,t0,tf,p0,s0,Nh)
% euler2: Euler method for 2-equations Cauchy problem
% Calling instruction: [tn,un,vn]=euler2(f1,f2,t0,tf,p0,s0,Nh) 
% Approximation of the solution of the Cauchy problem 
% in two equations:
%             p'(t)=f1(t,p(t),s(t))   for t in [t0,tf]
%             s'(t)=f2(t,p(t),s(t))   for t in [t0,tf]
%             p(t0)=p0, s(t0)=s0
% Input:  f1,f2 = function handle of f1(t,p,s) and f2(t,p,s)
%         t0,tf = endpoints of interval
%         p0,s0 = initial conditions for p(t) and s(t) resp.
%         Nh    = number of points in discretisation (except t0)
% Output: tn    = vector of discretisation points (including t0)
%         un,vn = vectors of numerical solution 
%                 (including u0=p0 and v0=s0)
tn=linspace(t0,tf,Nh+1)'; % discretisation points
h=(tf-t0)/Nh;             % discretisation step
un=zeros(Nh+1,1); % initialises the vectors of the numerical 
%                   solution
vn=zeros(Nh+1,1);
un(1)=p0; vn(1)=s0; % saves initial conditions
for n=1:Nh % constructs the numerical solution by the 
%            Euler method
    un(n+1)=un(n)+h*f1(tn(n),un(n),vn(n));
    vn(n+1)=vn(n)+h*f2(tn(n),un(n),vn(n));
end
